# Card Game Analysis: Tools to analyse card games

This project was started with the motivation of showing how unfair the card game Daifugo is. Please note that the project is under active development, and there's still a lot of things to add.

## Install/Update/Uninstall with [pip](https://pypi.org/project/pip/)

The recommended way to install is by using [pip](https://pypi.org/project/pip/).

### Install

```shell
$ pip install card-game-analysis
```

### Update

```shell
$ pip install -U card-game-analysis
```

### Uninstall

```shell
$ pip uninstall card-game-analysis
```

## Documentation

Documentation is hosted on readthedocs.org:

https://card-game-analysis.readthedocs.io/en/latest

## Relevant links

[Standard 52-card deck Wikipedia article](https://en.wikipedia.org/wiki/Standard_52-card_deck)

[Daifugo Wikipedia article](https://en.wikipedia.org/wiki/Daifug%C5%8D)

## License

Card-game-analysis is [MIT licensed](https://github.com/nwnordahl/card-game-analysis/blob/master/LICENSE).